package com.zjsgfa.project.zjsgfa.service.impl;

import java.util.List;

import com.zjsgfa.project.zjsgfa.domain.SjSggyZjzhcs;
import com.zjsgfa.project.zjsgfa.mapper.SjSggyZjzhcsMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zjsgfa.project.zjsgfa.mapper.SjZjcsxxMapper;
import com.zjsgfa.project.zjsgfa.domain.SjZjcsxx;
import com.zjsgfa.project.zjsgfa.service.ISjZjcsxxService;

/**
 * 设计-钻具参数信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-08-18
 */
@Service
public class SjZjcsxxServiceImpl implements ISjZjcsxxService 
{
    @Autowired
    private SjZjcsxxMapper sjZjcsxxMapper;

    @Autowired
    private SjSggyZjzhcsMapper sjSggyZjzhcsMapper;

    /**
     * 查询设计-钻具参数信息
     * 
     * @param id 设计-钻具参数信息主键
     * @return 设计-钻具参数信息
     */
    @Override
    public SjZjcsxx selectSjZjcsxxById(Long id)
    {
        return sjZjcsxxMapper.selectSjZjcsxxById(id);
    }

    /**
     * 查询设计-钻具参数信息列表
     * 
     * @param sjZjcsxx 设计-钻具参数信息
     * @return 设计-钻具参数信息
     */
    @Override
    public List<SjZjcsxx> selectSjZjcsxxList(SjZjcsxx sjZjcsxx)
    {
        return sjZjcsxxMapper.selectSjZjcsxxList(sjZjcsxx);
    }

    /**
     * 新增设计-钻具参数信息
     * 
     * @param sjZjcsxx 设计-钻具参数信息
     * @return 结果
     */
    @Override
    public int insertSjZjcsxx(SjZjcsxx sjZjcsxx)
    {
        return sjZjcsxxMapper.insertSjZjcsxx(sjZjcsxx);
    }

    /**
     * 修改设计-钻具参数信息
     * 
     * @param sjZjcsxx 设计-钻具参数信息
     * @return 结果
     */
    @Override
    public int updateSjZjcsxx(SjZjcsxx sjZjcsxx)
    {
        SjSggyZjzhcs sjSggyZjzhcs= new SjSggyZjzhcs();
        sjSggyZjzhcs.setJh(sjZjcsxx.getJh());
        sjSggyZjzhcs.setKc(sjZjcsxx.getKc());
        SjSggyZjzhcs sjSggyZjzhcs1 = sjSggyZjzhcsMapper.selectSjSggyZjzhcsByZjzhcs(sjSggyZjzhcs);
        if(sjSggyZjzhcs1!=null){
            sjSggyZjzhcs1.setZtxh(sjZjcsxx.getZtxh());
            sjSggyZjzhcs1.setCc(sjZjcsxx.getCc()+"");
            sjSggyZjzhcs1.setSy(sjZjcsxx.getSy()+"");
            sjSggyZjzhcs1.setZjymd(sjZjcsxx.getZjymd()+"");
            sjSggyZjzhcs1.setZjpl(sjZjcsxx.getZjpl()+"");
            sjSggyZjzhcs1.setCj(sjZjcsxx.getCj());
            sjSggyZjzhcs1.setYj(sjZjcsxx.getYj());
            sjSggyZjzhcs1.setZjzy(sjZjcsxx.getZjzy());
            sjSggyZjzhcs1.setZjzs(sjZjcsxx.getZjzs());
            sjSggyZjzhcs1.setZjby(sjZjcsxx.getZjby());
            sjSggyZjzhcsMapper.updateSjSggyZjzhcs(sjSggyZjzhcs1);
        }else {
            sjSggyZjzhcs1=new SjSggyZjzhcs();
            sjSggyZjzhcs1.setJh(sjZjcsxx.getJh());
            sjSggyZjzhcs1.setKc(sjZjcsxx.getKc());
            sjSggyZjzhcs1.setJd(sjZjcsxx.getJd());
            sjSggyZjzhcs1.setZtxh(sjZjcsxx.getZtxh());
            sjSggyZjzhcs1.setCc(sjZjcsxx.getCc()+"");
            sjSggyZjzhcs1.setSy(sjZjcsxx.getSy()+"");
            sjSggyZjzhcs1.setZjymd(sjZjcsxx.getZjymd()+"");
            sjSggyZjzhcs1.setZjpl(sjZjcsxx.getZjpl()+"");
            sjSggyZjzhcs1.setCj(sjZjcsxx.getCj());
            sjSggyZjzhcs1.setYj(sjZjcsxx.getYj());
            sjSggyZjzhcs1.setZjzy(sjZjcsxx.getZjzy());
            sjSggyZjzhcs1.setZjzs(sjZjcsxx.getZjzs());
            sjSggyZjzhcs1.setZjby(sjZjcsxx.getZjby());
            sjSggyZjzhcsMapper.updateSjSggyZjzhcs(sjSggyZjzhcs1);
        }
        int i = sjZjcsxxMapper.updateSjZjcsxx(sjZjcsxx);
        return i;
    }

    /**
     * 批量删除设计-钻具参数信息
     * 
     * @param ids 需要删除的设计-钻具参数信息主键
     * @return 结果
     */
    @Override
    public int deleteSjZjcsxxByIds(Long[] ids)
    {
        return sjZjcsxxMapper.deleteSjZjcsxxByIds(ids);
    }

    /**
     * 删除设计-钻具参数信息信息
     * 
     * @param id 设计-钻具参数信息主键
     * @return 结果
     */
    @Override
    public int deleteSjZjcsxxById(Long id)
    {
        return sjZjcsxxMapper.deleteSjZjcsxxById(id);
    }
}
